@@ -51,7 +51,7 @@ fn extract_libbpf_headers_to_disk() -> Result<TempDir> {
     let tempdir = TempDir::new()?;
     let dir = tempdir.path().join("bpf");
     fs::create_dir_all(&dir)?;
-    for (filename, contents) in libbpf_sys::API_HEADERS {
+    for (filename, contents) in libbpf_sys::API_HEADERS.iter() {
         let path = dir.as_path().join(filename);
         let mut file = OpenOptions::new().write(true).create(true).open(path)?;
         file.write_all(contents.as_bytes())?;
