@@ -886,6 +886,15 @@ fn assert_definition(btf: &Btf, btf_item: u32, expected_output: &str) {
     let ao = actual_output.trim_end().trim_start();
     let eo = expected_output.trim_end().trim_start();
 
+    println!("---------------");
+    println!("expected output");
+    println!("---------------");
+    println!("{}", eo);
+    println!("-------------");
+    println!("actual output");
+    println!("-------------");
+    println!("{}", ao);
+
     assert_eq!(eo, ao);
 }
 
@@ -1259,13 +1268,18 @@ union Foo foo;
 "#;
 
     let expected_output = r#"
-#[derive(Debug, Copy, Clone)]
+#[derive(Copy, Clone)]
 #[repr(C)]
 pub union Foo {
     pub x: i32,
     pub y: u32,
     pub z: [i8; 128],
 }
+impl std::fmt::Debug for Foo {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        write!(f, "(???)")
+    }
+}
 "#;
 
     let btf = build_btf_prog(prog_text);
@@ -1582,18 +1596,28 @@ pub struct Foo {
     pub baz: __anon_2,
     pub w: i32,
 }
-#[derive(Debug, Copy, Clone)]
+#[derive(Copy, Clone)]
 #[repr(C)]
 pub union __anon_1 {
     pub y: [u8; 10],
     pub z: [u16; 16],
 }
-#[derive(Debug, Copy, Clone)]
+impl std::fmt::Debug for __anon_1 {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        write!(f, "(???)")
+    }
+}
+#[derive(Copy, Clone)]
 #[repr(C)]
 pub union __anon_2 {
     pub w: u32,
     pub u: *mut u64,
 }
+impl std::fmt::Debug for __anon_2 {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        write!(f, "(???)")
+    }
+}
 "#;
 
     let btf = build_btf_prog(prog_text);
@@ -1706,12 +1730,17 @@ pub struct __anon_1 {
     pub y: [u8; 10],
     pub z: [u16; 16],
 }
-#[derive(Debug, Copy, Clone)]
+#[derive(Copy, Clone)]
 #[repr(C)]
 pub union __anon_2 {
     pub a: *mut i8,
     pub b: i32,
 }
+impl std::fmt::Debug for __anon_2 {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        write!(f, "(???)")
+    }
+}
 #[derive(Debug, Default, Copy, Clone)]
 #[repr(C)]
 pub struct __anon_3 {
@@ -1719,12 +1748,17 @@ pub struct __anon_3 {
     __pad_4: [u8; 4],
     pub u: *mut u64,
 }
-#[derive(Debug, Copy, Clone)]
+#[derive(Copy, Clone)]
 #[repr(C)]
 pub union __anon_4 {
     pub c: u8,
     pub d: [u64; 5],
 }
+impl std::fmt::Debug for __anon_4 {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        write!(f, "(???)")
+    }
+}
 "#;
 
     let btf = build_btf_prog(prog_text);
@@ -1782,12 +1816,17 @@ pub struct __anon_1 {
     pub y: [u8; 10],
     pub z: [u16; 16],
 }
-#[derive(Debug, Copy, Clone)]
+#[derive(Copy, Clone)]
 #[repr(C)]
 pub union __anon_2 {
     pub a: *mut i8,
     pub b: i32,
 }
+impl std::fmt::Debug for __anon_2 {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        write!(f, "(???)")
+    }
+}
 #[derive(Debug, Default, Copy, Clone)]
 #[repr(C)]
 pub struct __anon_3 {
@@ -1795,12 +1834,18 @@ pub struct __anon_3 {
     __pad_4: [u8; 4],
     pub u: *mut u64,
 }
-#[derive(Debug, Copy, Clone)]
+#[derive(Copy, Clone)]
 #[repr(C)]
 pub union __anon_4 {
     pub c: u8,
     pub d: [u64; 5],
-}"#;
+}
+impl std::fmt::Debug for __anon_4 {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        write!(f, "(???)")
+    }
+}
+"#;
     let btf = build_btf_prog(prog_text);
 
     let struct_foo = find_type_in_btf!(btf, Struct, "Foo");
